@@ -104,8 +104,7 @@ cria_layout_block_class_init (CriaLayoutBlockClass	* cria_layout_block_class)
 			g_param_spec_string (
 				"title",
 				"Title",
-				// TODO add documentation
-				"",
+				"The Title of this block, used to connect slide blocks to their layouts",
 				_("untitled"),
 				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
 			);
@@ -115,8 +114,7 @@ cria_layout_block_class_init (CriaLayoutBlockClass	* cria_layout_block_class)
 			g_param_spec_double (
 				"pos-x",
 				"X-Position",
-				// TODO add documentation
-				"",
+				"The Position of the topleft corner of the layout box",
 				-G_MAXDOUBLE,
 				G_MAXDOUBLE,
 				0,
@@ -127,9 +125,8 @@ cria_layout_block_class_init (CriaLayoutBlockClass	* cria_layout_block_class)
 			PROP_POS_X_UNIT,
 			g_param_spec_enum (
 				"pos-x-unit",
-				"X-Position",
-				// TODO add documentation
-				"",
+				"X-Position unit",
+				"The unit for the x position value in \"pos-x\".",
 				CRIA_TYPE_UNIT,
 				CRIA_UNIT_PIXEL,
 				G_PARAM_READWRITE | G_PARAM_CONSTRUCT)
@@ -284,6 +281,9 @@ cria_layout_block_get_default_text (CriaLayoutBlock *self)
 {
 	g_return_val_if_fail (CRIA_IS_LAYOUT_BLOCK (self), NULL);
 
+	g_debug ("cria_layout_block_get_default_text():");
+	g_message ("%s", self->default_text);
+
 	return self->default_text;
 }
 
