@@ -438,6 +438,14 @@ cria_sax_0_0_1_characters (
 		char	**strv,
 			**iterator;
 
+		/* TODO this code totally misbehaved (see the if-statement above)
+		 * we need some new cdata parsing code. something like
+		 * 1. replace any whitespace character with a space
+		 * 2. replace any two spaces with one until there are no dupilicated
+		 *    spaces
+		 * 3. cut trailing space
+		 * 4. cut leading space if cdata was empty
+		 */
 		/* split the string into single lines to be processed */
 		strv = g_strsplit (
 				str,
@@ -452,8 +460,9 @@ cria_sax_0_0_1_characters (
 			g_strstrip (*iterator);
 
 			/* append one whitespace between lines */
-			if (strlen (data->cdata->str))
-				g_string_append (data->cdata, " ");
+			/* but don't do if we already have '\n' there */
+			//if (strlen (data->cdata->str) && (data->cdata->str[strlen (data->cdata->str) - 1] != '\n'))
+				//g_string_append (data->cdata, " ");
 
 			g_string_append (data->cdata, *iterator);
 		}
@@ -594,6 +603,7 @@ cria_sax_0_0_1_element_block_end (Sax001Data * data)
 			g_string_free (data->cdata, TRUE);
 			data->cdata = NULL;
 		}
+
 		cria_slide_add_block (
 				CRIA_SLIDE (g_list_nth (data->tags, g_list_length(data->tags) - 2)->data),
 				CRIA_SLIDE_BLOCK (g_list_last (data->tags)->data));
@@ -604,6 +614,18 @@ cria_sax_0_0_1_element_block_end (Sax001Data * data)
 			g_list_last (data->tags)->data);
 }
 
+static void
+cria_sax_0_0_1_element_br_end (
+		Sax001Data	* data)
+{
+	if (data->cdata)
+	{
+		g_string_append (
+				data->cdata,
+				"\n");
+	}
+}
+
 static void
 cria_sax_0_0_1_element_description_start (
 		GHashTable	* hash_table,
@@ -782,6 +804,7 @@ static cria_tag_data cria_0_0_1_tag_data[] =
 {
 	{"background",		&cria_sax_0_0_1_element_background_start,	&cria_sax_0_0_1_element_background_end		},
 	{"block",		&cria_sax_0_0_1_element_block_start,		&cria_sax_0_0_1_element_block_end		},
+	{"br",			NULL,						&cria_sax_0_0_1_element_br_end			},
 	{"description",		&cria_sax_0_0_1_element_description_start,	&cria_sax_0_0_1_element_description_end		},
 	{"layout",		&cria_sax_0_0_1_element_layout_start,		&cria_sax_0_0_1_element_layout_end		},
 	{"presentation",	&cria_sax_0_0_1_element_presentation_start,	&cria_sax_0_0_1_element_presentation_end	},
