@@ -558,14 +558,17 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 			gdouble		  xpos  = cria_layout_block_get_pos_x (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
 					  ypos  = cria_layout_block_get_pos_y (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
 					  width = cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
-					  height= cria_layout_block_get_height(cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height;
+					  height= cria_layout_block_get_height(cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
+					  font_size = cria_layout_block_get_font_size (cria_layout_get_block (layout, *iterator));
+
+			font_size = (font_size <= 0)?1:font_size;
 
 			if (alignment == CRIA_ALIGNMENT_LEFT)
 			{
 				g_debug ("cria_slide_show_render_slide(%s:%i): left rendering:", __FILE__, __LINE__);
 				xpos = xpos;
 				ypos = ypos;
-				gtk_anchor= GTK_ANCHOR_NORTH_EAST;
+				gtk_anchor= GTK_ANCHOR_NORTH_WEST;
 				gtk_align = GTK_JUSTIFY_LEFT;
 			}
 			else if (alignment == CRIA_ALIGNMENT_CENTER)
@@ -581,7 +584,7 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 				g_debug ("cria_slide_show_render_slide(%s:%i): right rendering:", __FILE__, __LINE__);
 				xpos = xpos + width;
 				ypos = ypos;
-				gtk_anchor= GTK_ANCHOR_NORTH_WEST;
+				gtk_anchor= GTK_ANCHOR_NORTH_EAST;
 				gtk_align = GTK_JUSTIFY_RIGHT;
 			}
 			else
@@ -596,13 +599,13 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 						self->priv->group,
 						gnome_canvas_text_get_type (),
 						"anchor", gtk_anchor,
-						"clip", TRUE,
-						"clip-height", cria_layout_block_get_height (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
-						"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
+					//	"clip", TRUE,
+					//	"clip-height", cria_layout_block_get_height (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_height,
+					//	"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, *iterator)),
 						"justification", gtk_align,
 						"markup", cria_slide_block_get_processed_content (cria_slide_get_block (slide, *iterator)),
-						"size-points", cria_layout_block_get_font_size (cria_layout_get_block (layout, *iterator)),
+						"size-points", font_size,
 						"size-set", TRUE,
 #warning 4 assertions that unit is percent
 						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
@@ -625,7 +628,7 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 						"clip-width", cria_layout_block_get_width (cria_layout_get_block (layout, *iterator)) / 100 * CRIA_SLIDE_SHOW_GET_CLASS (self)->screen_width,
 						"family", cria_layout_block_get_font_family (cria_layout_get_block (layout, *iterator)),
 						"justification", gtk_align,
-						"size-points", cria_layout_block_get_font_size (cria_layout_get_block (layout, *iterator)),
+						"size-points", font_size,
 						"size-set", TRUE,
 						"text", (cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator))==_("block has no content"))?"":cria_layout_block_get_default_text (cria_layout_get_block (layout, *iterator)),
 						// TODO use something like cria_slide_show_unit_to_double (slide_show, unit, length)
@@ -667,8 +670,6 @@ cria_slide_show_render_slide (CriaSlideShow *self)
 		g_free (title);
 	}
 
-	// TODO render slide content
-	
 	/* update window's title */
 	title = g_strdup_printf (TITLE_STRING, cria_slide_get_title (slide));
 	g_debug ("cria_slide_show_render(%i): title[%i] (dev-count): \"%s\"", __LINE__, cria_slide_show_get_slide (self), title);
